@@ -1,6 +1,6 @@
 package PDF::Create::Page;
 
-our $VERSION = '1.34';
+our $VERSION = '1.35';
 
 =encoding utf8
 
@@ -10,7 +10,7 @@ PDF::Create::Page - PDF pages tree for PDF::Create
 
 =head1 VERSION
 
-Version 1.34
+Version 1.35
 
 =cut
 
@@ -634,7 +634,7 @@ and 800  will  be assumed. All subsequent invocations can omit all but the strin
 parameters.
 
 ATTENTION:There is no provision for changing pages.If you run out of space on the
-current page this will draw the string(s) outside the page and it will be invisble.
+current page this will draw the string(s) outside the page and it will be invisible.
 
 =cut
 
